@@ -1003,6 +1003,13 @@ do_sound_action (Acme *acme, int type)
 	GtkWidget *progress;
 	gboolean muted;
 	int vol;
+	int vol_step;
+
+	vol_step = gconf_client_get_int (acme->conf_client,
+			"/apps/acme/volume_step", NULL);
+
+	if (vol_step == 0)
+		vol_step = VOLUME_STEP;
 
 	if (acme->dialog_timeout != 0)
 	{
@@ -1022,7 +1029,7 @@ do_sound_action (Acme *acme, int type)
 		{
 			acme_volume_mute_toggle(acme->volobj);
 		} else {
-			acme_volume_set_volume (acme->volobj, vol - VOLUME_STEP);
+			acme_volume_set_volume (acme->volobj, vol - vol_step);
 		}
 		break;
 	case VOLUME_UP_KEY:
@@ -1030,7 +1037,7 @@ do_sound_action (Acme *acme, int type)
 		{
 			acme_volume_mute_toggle(acme->volobj);
 		} else {
-			acme_volume_set_volume (acme->volobj, vol + VOLUME_STEP);
+			acme_volume_set_volume (acme->volobj, vol + vol_step);
 		}
 		break;
 	}
